# Pylotable

[![example workflow](https://github.com/SamuelAndresPascal/cosmoloj-py/actions/workflows/pylotable.yml/badge.svg)](https://github.com/SamuelAndresPascal/cosmoloj-py/actions)

[![Anaconda-Server Badge](https://anaconda.org/cosmoloj/pylotable/badges/version.svg)](https://anaconda.org/cosmoloj/pylotable)
[![Anaconda-Server Badge](https://anaconda.org/cosmoloj/pylotable/badges/latest_release_date.svg)](https://anaconda.org/cosmoloj/pylotable)
[![Anaconda-Server Badge](https://anaconda.org/cosmoloj/pylotable/badges/latest_release_relative_date.svg)](https://anaconda.org/cosmoloj/pylotable)
[![Anaconda-Server Badge](https://anaconda.org/cosmoloj/pylotable/badges/platforms.svg)](https://anaconda.org/cosmoloj/pylotable)
[![Anaconda-Server Badge](https://anaconda.org/cosmoloj/pylotable/badges/license.svg)](https://anaconda.org/cosmoloj/pylotable)

[![PyPI repository Badge](https://badge.fury.io/py/pylotable.svg)](https://badge.fury.io/py/pylotable)

* [Documentation](#documentation)


## Documentation

[Latest release](https://cosmoloj.com/mkdocs/pylotable/latest/)

[Trunk](https://cosmoloj.com/mkdocs/pylotable/master/)
